@@ -1,11 +1,11 @@
 # ------------------------------------------------------------------------------
 # anonymous missing node
 
-for (i in vec
+{{
+  1 + 2
+}
 
 # ------------------------------------------------------------------------------
 # named missing node
 
-1 +
-
-;
+while (a > b)
